import QtQuick 1.1
import com.nokia.meego 1.1

Page {

    property bool nextWeek: false

    function selectDay(){
        var datum= new Date();
        var tag = datum.getDay();
        setDay(tag);
        days.exclusive = true;
        switch(tag){
        case 1: days.checkedButton=btn_mo; break;
        case 2: days.checkedButton=btn_di; break;
        case 3: days.checkedButton=btn_mi; break;
        case 4: days.checkedButton=btn_do; break;
        case 5: days.checkedButton=btn_fr; break;
        default: days.exclusive=false;
            days.checkedButton=null;
            break;
        }
    }

    Component.onCompleted: {
        selectDay();
    }

    SelectionDialog{
        id: selWoche
        titleText: "Woche"
        model: ListModel{
            ListElement{
                name: "Diese Woche"
            }
            ListElement{
                name: "Nächste Woche"
            }
        }

        onSelectedIndexChanged: {
            nextWeek=selectedIndex>0;
            console.log(nextWeek);
            selectDay();
        }
    }

    Rectangle{
        id: header
        width: parent.width
        height: 70
        color: "#7D9AAA"
        Label {
            elide: Text.ElideRight
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left
            anchors.leftMargin: 16
            anchors.right: parent.right
            anchors.rightMargin: 16
            text: "Mensaplan (" + (!nextWeek?"diese Woche)":"nächste Woche)")
            horizontalAlignment: Text.AlignHCenter

            platformStyle: LabelStyle {
                textColor: "black"
                fontPixelSize: 28
            }
        }

        MouseArea{
            anchors.fill: parent
            onClicked: selWoche.open();
        }
    }

    Flickable{
        id:flick
        anchors.bottom: days.top
        anchors.top: header.bottom;
        width:parent.width
        boundsBehavior: Flickable.StopAtBounds
        clip: true
        anchors.rightMargin: 10
        anchors.leftMargin: 10
        anchors.bottomMargin: 10
        anchors.topMargin: 10

        ListView{
            id: lv
            width: parent.width
            anchors.fill: parent

            anchors.rightMargin: 10
            anchors.leftMargin: 10
            anchors.bottomMargin: 10
            anchors.topMargin: 10

            spacing: 15;

            model: mensaModel
            delegate: speise

            footer: Column{
                width:parent.width
                spacing: 15
                Button{
                    text: "Bistro"
                    anchors.horizontalCenter: parent.horizontalCenter
                    onClicked: {
                        var url="http://www.studentenwerk-ulm.de/fileadmin/externe_websites/ext.studentenwerk/bilder/Speisepläne/Bistro";
                        var n =nextWeek?kw()+1:kw();
                        url += (n>9)?"":"0";
                        url += n;
                        url+=".pdf";
                        console.log(url);
                        Qt.openUrlExternally(url);
                    }
                }
                Button{
                    text: "Cafete Nord"
                    anchors.horizontalCenter: parent.horizontalCenter
                    onClicked: {
                        var url="http://www.studentenwerk-ulm.de/fileadmin/externe_websites/ext.studentenwerk/bilder/Speisepläne/CB";
                        var n =nextWeek?kw()+1:kw();
                        url += (n>9)?"":"0";
                        url += n;
                        url+=".pdf";
                        console.log(url);
                        Qt.openUrlExternally(url);
                    }

                }
            }

        }

    }

    ButtonRow{
        id:days
        //anchors.top:flick.bottom
        anchors.bottom: parent.bottom
        anchors.bottomMargin: 0
        width: parent.width
        TabButton{
            id:btn_mo
            text:"Mo"
            onClicked: {
                setDay(1);
            }
        }

        TabButton{
            id:btn_di
            text:"Di"
            onClicked: {
                setDay(2);
            }
        }

        TabButton{
            id:btn_mi
            text:"Mi"
            onClicked: {
                setDay(3);
            }
        }

        TabButton{
            id:btn_do
            text:"Do"
            onClicked: {
                setDay(4)
            }
        }

        TabButton{
            id:btn_fr
            text:"Fr"
            onClicked: {
                setDay(5);
            }
        }
    }

    Mensaplan{
        id:mensaModel
    }

    SpeiseDelegate{
        id:speise
    }

    function setDay(day){
        var datum= new Date();
        var heute = datum.getDay();
        datum.setDate(datum.getDate()-(heute-day)+(nextWeek?7:0));
        var a = datum.getFullYear();
        var m = datum.getMonth()+1;
        var d = datum.getDate();
        mensaModel.date= a+'-';//+m+'-'+d;
        mensaModel.date += ((m<10)?"0":"")+m+'-';
        mensaModel.date += ((d<10)?"0":"")+d;
        days.exclusive = true;
        var tmp = mensaModel.date;
        console.log(tmp);
    }

    function kw(){
        var Datum=new Date();
        var DoDat=donnerstag(Datum);
        var kwjahr=DoDat.getFullYear();
        var DoKW1=donnerstag(new Date(kwjahr,0,4));
        return Math.floor(1.5+(DoDat.getTime()-DoKW1.getTime())/86400000/7)
    }

    function donnerstag(datum) {
        var Do=new Date();
        Do.setTime(datum.getTime() + (3-((datum.getDay()+6) % 7)) * 86400000);
        return Do;
    }
}


